@@ -3,7 +3,10 @@ from pythonwhat import check_funcs, check_object
 from pythonwhat.check_function import check_function
 from pythonwhat.check_has_context import has_context
 from pythonwhat.test_funcs.test_data_frame import check_df
-from pythonwhat.test_funcs.test_dictionary import check_dict
+from pythonwhat.test_funcs.test_student_typed import check_code
+from pythonwhat.test_funcs.test_output_contains import check_output
+from pythonwhat.test_funcs.test_import import check_import
+
 from pythonwhat import test_funcs
 from functools import partial
 import inspect
@@ -70,5 +73,7 @@ for k in ['check_object', 'is_instance', 'has_equal_key', 'has_key']:
     scts[k] = getattr(check_object, k)
 
 scts['check_df'] = check_df
-scts['check_dict'] = check_dict
+scts['check_import'] = check_import
+scts['check_output'] = check_output
+scts['check_code'] = check_code
 scts['has_context'] = has_context
